cli

package
v0.19.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: BSD-2-Clause Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute is the entry point called from main. It creates a root context with signal handling and delegates to Run.

func Run

func Run(ctx context.Context, args []string) error

Run builds and executes the cobra command tree with the given args.

Types

This section is empty.

Jump to