watcher

package
v0.19.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 22, 2026 License: BSD-2-Clause Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Watcher

type Watcher interface {
	Watch(ctx context.Context) error
}

Watcher watches the vault tasks directory and notifies on matching task changes.

func NewWatcher

func NewWatcher(cfg config.Config, notifiers []notify.Notifier) Watcher

NewWatcher returns a Watcher that watches all configured vaults and fans out matching task events to all configured watcher entries.

Jump to